@@ -1030,8 +1030,9 @@ flow_images_from_dataframe <- function(
 #' @param seed Optional random seed for shuffling and transformations.
 #' @param validation_split Optional float between 0 and 1, fraction of data to
 #'   reserve for validation.
-#' @param subset One of "training" or "validation". Only used if
-#'   validation_split is set.
+#' @param subset One of "training", "validation", or "both" (available for TF>=2.10).
+#'   Only used if validation_split is set. When `subset="both"`, the utility returns
+#'   a tuple of two datasets (the training and validation datasets respectively).
 #' @param interpolation String, the interpolation method used when resizing
 #'   images. Defaults to bilinear. Supports bilinear, nearest, bicubic, area,
 #'   lanczos3, lanczos5, gaussian, mitchellcubic.
@@ -1102,6 +1103,9 @@ image_dataset_from_directory <- function(
     labels = function(l) if(is.character(l)) l else as.integer(l)
   ))
 
+  if (identical(subset, "both") && tensorflow::tf_version() < "2.10")
+    stop('subset="both" is only available for TF>=2.10')
+
   out <- do.call(keras$preprocessing$image_dataset_from_directory, args)
   class(out) <- unique(c("tf_dataset", class(out)))
   out
